// This implementation is derived from the solution provided by [baydisng13] in the discussion thread:
// https://github.com/shadcn-ui/ui/discussions/3875

import { create } from "zustand";

interface ConfirmationState {
  open: boolean;
  title: string | null;
  description: string | null;
  cancelLabel: string | null;
  actionLabel: string | null;
  onCancel: () => void;
  onAction: () => void;
}

interface ConfirmationActions {
  openConfirmation: (data: {
    title: string;
    description: string;
    cancelLabel: string;
    actionLabel: string;
    onCancel: () => void;
    onAction: () => void;
  }) => void;
  closeConfirmation: () => void;
}

const useConfirmationStore = create<ConfirmationState & ConfirmationActions>(
  (set) => ({
    open: false,
    title: null,
    description: null,
    cancelLabel: null,
    actionLabel: null,
    onCancel: () => {},
    onAction: () => {},
    openConfirmation: (data) =>
      set(() => ({
        open: true,
        title: data.title,
        description: data.description,
        cancelLabel: data.cancelLabel,
        actionLabel: data.actionLabel,
        onCancel: data.onCancel,
        onAction: data.onAction,
      })),
    closeConfirmation: () => {
      // Close the confirmation dialog by setting the 'open' state to false.
      set((state) => ({
        ...state,
        open: false,
      }));
      // After a short delay (100ms), reset the dialog's state to its initial values.
      // This delay ensures that the dialog is fully closed before resetting,
      // preventing any visual flickering or UI inconsistencies.
      setTimeout(() => {
        set((state) => ({
          ...state,
          title: null,
          description: null,
          cancelLabel: null,
          actionLabel: null,
          onCancel: () => {},
          onAction: () => {},
        }));
      }, 100);
    },
  })
);

export default useConfirmationStore;
